==> Gambio v4.1.1.2.zip: Vollversion GX v4.1.1.2/Shopsystem/Dateien/lang/german/original_sections/admin/gm_pdf_action.lang.inc.php <==
<?php
/* --------------------------------------------------------------
	gm_pdf_action.lang.inc.php 2018-07-24
	Gambio GmbH
	http://www.gambio.de
	Copyright (c) 2018 Gambio GmbH
	Released under the GNU General Public License (Version 2)
	[http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

$t_language_text_section_content_array = array(
	'BUTTON_SAVE'                                => 'Speichern',
	'ERROR_NOT_NUMERIC'                          => ' muss numerisch sein!',
	'GM_LOGO_PDF_USE'                            => 'Logo verwenden?',
	'GM_PDF_INVOICE_USE_CURRENT_DATE'            => 'Zu verwendendes Rechnungsdatum',
	'GM_PDF_INVOICE_USE_CURRENT_DATE_FALSE'      => 'Datum festlegen',
	'GM_PDF_INVOICE_USE_CURRENT_DATE_TRUE'       => 'Immer aktuelles Datum verwenden',
	'GM_PDF_INVOICE_USE_MANUAL_DATE_INFO'        => 'Bitte beachten Sie, dass alle neuen Rechnungen mit demselben Datum versehen werden.',
	'GM_PDF_ORDER_STATUS_INVOICE'                => 'Bestellstatus nach Rechnungserstellung',
	'GM_PDF_ORDER_STATUS_INVOICE_MAIL'           => 'Bestellstatus nach E-Mail Rechnungsversand',
	'GM_PDF_ORDER_STATUS_NOT'                    => 'nicht ändern',
	'GM_PDF_PACKING_SLIP_USE_CURRENT_DATE'       => 'Zu verwendendes Lieferscheindatum',
	'GM_PDF_PACKING_SLIP_USE_CURRENT_DATE_FALSE' => 'Datum festlegen',
	'GM_PDF_PACKING_SLIP_USE_CURRENT_DATE_TRUE'  => 'Immer aktuelles Datum verwenden',
	'GM_PDF_PACKING_SLIP_USE_MANUAL_DATE_INFO'   => 'Bitte beachten Sie, dass alle neuen Lieferscheine mit demselben Datum versehen werden.',
	'GM_PDF_TABLE_HEADER_BANK_DATA_COLUMN'       => 'Spalte enthält Bankverbindung',
	'GM_PDF_TABLE_HEADER_BANK_DATA_TOOLTIP'      => 'Einige Zahlungsweisen entfernen beim Erstellen der Rechnung eine Spalte, welche die Bankverbindung enthält und fügen stattdessen eigenen Inhalt in die Rechnung ein.',
	'GM_PDF_TABLE_HEADER_COLUMN_CONTENT'         => 'Spalteninhalt',
	'GM_PDF_TITLE_ALLOW_COPYING'                 => 'Kopieren der internen Texte und Grafiken erlauben',
	'GM_PDF_TITLE_ALLOW_MODIFYING'               => 'Modifizieren des PDF-Dokumentes erlauben',
	'GM_PDF_TITLE_ALLOW_NOTIFYING'               => 'Kommentieren des PDF-Dokumentes erlauben',
	'GM_PDF_TITLE_BOTTOM_MARGIN'                 => 'Einzug unten',
	'GM_PDF_TITLE_CANCEL_FONT_FACE'              => 'Storno-Hinweis',
	'GM_PDF_TITLE_CELL_HEIGHT'                   => 'Höhe der Zellen',
	'GM_PDF_TITLE_CHOOSE_LOGO'                   => 'Logo auswählen',
	'GM_PDF_TITLE_COMPANY_ADRESS_LEFT'           => 'Firmenadresse links',
	'GM_PDF_TITLE_COMPANY_ADRESS_RIGHT'          => 'Firmenadresse rechts',
	'GM_PDF_TITLE_COMPANY_LEFT_FONT_FACE'        => 'Firmenadresse links',
	'GM_PDF_TITLE_COMPANY_RIGHT_FONT_FACE'       => 'Firmenadresse rechts',
	'GM_PDF_TITLE_CONDITIONS'                    => 'AGB',
	'GM_PDF_TITLE_CONDITIONS_FONT_FACE'          => 'AGB/Widerruf',
	'GM_PDF_TITLE_CUSTOMER_ADR_POS'              => 'mm Einzug der Kunden Adresse nach oben',
	'GM_PDF_TITLE_CUSTOMER_FONT_FACE'            => 'Kundenadresse',
	'GM_PDF_TITLE_DEFAULT_FONT_FACE'             => 'Standardschrift',
	'GM_PDF_TITLE_DISPLAY_LAYOUT'                => 'Seitenlayout der PDF im Reader',
	'GM_PDF_TITLE_DISPLAY_ZOOM'                  => 'Zoomfaktor der PDF im Reader',
	'GM_PDF_TITLE_DRAW_COLOR'                    => 'Farbe für Linien',
	'GM_PDF_TITLE_EMAIL_SUBJECT'                 => 'E-Mail Betreff',
	'GM_PDF_TITLE_EMAIL_SUBJECT_INFO'            => '<small>Platzhalter: Rechnungsnr: {INVOICE_ID} Bestellnr: {ORDER_ID} Bestelldatum: {DATE}</small>',
	'GM_PDF_TITLE_EMAIL_TEXT'                    => 'Nachricht',
	'GM_PDF_TITLE_EMAIL_TEXT_INFO'               => '<small>Platzhalter: Anrede: {SALUTATION} Kundenname: {CUSTOMER}  Rechnungsnr: {INVOICE_ID} Bestellnr: {ORDER_ID} Bestelldatum: {DATE}</small>',
	'GM_PDF_TITLE_FIX_HEADER'                    => 'Kopfteil fixieren?',
	'GM_PDF_TITLE_FOOTER_CELL_1'                 => 'Fußteil erste Spalte',
	'GM_PDF_TITLE_FOOTER_CELL_2'                 => 'Fußteil zweite Spalte',
	'GM_PDF_TITLE_FOOTER_CELL_3'                 => 'Fußteil dritte Spalte',
	'GM_PDF_TITLE_FOOTER_CELL_4'                 => 'Fußteil vierte Spalte',
	'GM_PDF_TITLE_FOOTER_FONT_FACE'              => 'Fußteil',
	'GM_PDF_TITLE_HEADING_CANCELLATION_INVOICE'  => 'Überschrift Stornorechnung',
	'GM_PDF_TITLE_HEADING_CONDITIONS'            => 'Überschrift AGB',
	'GM_PDF_TITLE_HEADING_CONDITIONS_FONT_FACE'  => 'Überschrift AGB/Widerruf',
	'GM_PDF_TITLE_HEADING_FONT_FACE'             => 'Überschrift',
	'GM_PDF_TITLE_HEADING_INFO_TEXT_INVOICE'     => 'Überschrift Rechnungshinweis',
	'GM_PDF_TITLE_HEADING_INFO_TEXT_PACKINGSLIP' => 'Überschrift Lieferhinweis',
	'GM_PDF_TITLE_HEADING_INVOICE'               => 'Überschrift Rechnung',
	'GM_PDF_TITLE_HEADING_MARGIN_BOTTOM'         => 'Einzug der Überschrift nach unten',
	'GM_PDF_TITLE_HEADING_MARGIN_TOP'            => 'Einzug der Überschrift nach oben',
	'GM_PDF_TITLE_HEADING_ORDER_FONT_FACE'       => 'Bestell-Tabellenkopf',
	'GM_PDF_TITLE_HEADING_ORDER_INFO_FONT_FACE'  => 'Überschrift Hinweis',
	'GM_PDF_TITLE_HEADING_PACKINGSLIP'           => 'Überschrift Lieferschein',
	'GM_PDF_TITLE_HEADING_WITHDRAWAL'            => 'Überschrift Widerruf',
	'GM_PDF_TITLE_INFO_TEXT_INVOICE'             => 'Hinweistext Rechnung',
	'GM_PDF_TITLE_INFO_TEXT_PACKINGSLIP'         => 'Hinweistext Lieferschein',
	'GM_PDF_TITLE_INFO_TITLE_INVOICE'            => 'Hinweistitel Rechnung',
	'GM_PDF_TITLE_INFO_TITLE_PACKINGSLIP'        => 'Hinweistitel Lieferschein',
	'GM_PDF_TITLE_INVOICES_EMAIL_SUBJECT'        => 'E-Mail Betreff (mehrere Rechnungen)',
	'GM_PDF_TITLE_INVOICES_EMAIL_SUBJECT_INFO'   => '<small>Platzhalter: Rechnungsnummern: {INVOICE_NUMBERS} Bestellnr: {ORDER_ID} Bestelldatum: {DATE}</small>',
	'GM_PDF_TITLE_LEFT_MARGIN'                   => 'Einzug links',
	'GM_PDF_TITLE_ORDER_FONT_FACE'               => 'Bestell-Tabelle',
	'GM_PDF_TITLE_ORDER_INFO_FONT_FACE'          => 'Hinweistext',
	'GM_PDF_TITLE_ORDER_INFO_MARGIN_TOP'         => 'Einzug des Hinweises nach oben',
	'GM_PDF_TITLE_ORDER_TOTAL_FONT_FACE'         => 'Bestell-Zusammenfassung',
	'GM_PDF_TITLE_RIGHT_MARGIN'                  => 'Einzug rechts',
	'GM_PDF_TITLE_TOP_MARGIN'                    => 'Einzug oben',
	'GM_PDF_TITLE_USE_CONDITIONS'                => 'AGB verwenden?',
	'GM_PDF_TITLE_USE_CUSTOMER_CODE'             => 'Kundennummer verwenden?',
	'GM_PDF_TITLE_USE_CUSTOMER_COMMENT'          => 'Kundenkommentar verwenden?',
	'GM_PDF_TITLE_USE_DATE'                      => 'aktuelles Datum verwenden?',
	'GM_PDF_TITLE_USE_FOOTER'                    => 'Fußteil verwenden?',
	'GM_PDF_TITLE_USE_HEADER'                    => 'Kopfteil verwenden?',
	'GM_PDF_TITLE_USE_INFO'                      => 'Hinweis verwenden?',
	'GM_PDF_TITLE_USE_INFO_TEXT'                 => 'Hinweistext verwenden?',
	'GM_PDF_TITLE_USE_INVOICE_CODE'              => 'Rechnungsnummer verwenden?',
	'GM_PDF_TITLE_USE_ORDER_CODE'                => 'Bestellnummer verwenden?',
	'GM_PDF_TITLE_USE_ORDER_DATE'                => 'Bestelldatum verwenden?',
	'GM_PDF_TITLE_USE_PACKING_CODE'              => 'Liefernummer verwenden?',
	'GM_PDF_TITLE_USE_PRODUCTS_MODEL'            => 'Spalte "Artikel Nr" Verwenden?',
	'GM_PDF_TITLE_USE_PROTECTION'                => 'PDF Dokument schützen?',
	'GM_PDF_TITLE_USE_WITHDRAWAL'                => 'Widerruf verwenden?',
	'GM_PDF_TITLE_WITHDRAWAL'                    => 'Widerruf',
	'MENU_TITLE_CONDITIONS'                      => 'AGB/Widerruf',
	'MENU_TITLE_CONF'                            => 'Konfiguration',
	'MENU_TITLE_CONTENT'                         => 'Inhalt',
	'MENU_TITLE_DISPLAY'                         => 'Anzeige',
	'MENU_TITLE_EMAIL_TEXT'                      => 'E-Mail Rechnung',
	'MENU_TITLE_FONTS'                           => 'Schriften',
	'MENU_TITLE_FOOTER'                          => 'Fußteil',
	'MENU_TITLE_HEADER'                          => 'Kopfteil',
	'MENU_TITLE_INVOICING'                       => 'Bestellstatus und Rechnungs-/Lieferscheindatum',
	'MENU_TITLE_LAYOUT'                          => 'Layout',
	'MENU_TITLE_LOGO'                            => 'Logo',
	'MENU_TITLE_ORDER_INFO'                      => 'Hinweistexte',
	'MENU_TITLE_PREVIEW'                         => 'Vorschau',
	'MENU_TITLE_PROTECTION'                      => 'Sicherheit',
	'NOTE_PREVIEW'                               => 'Bitte beachten Sie, dass in der Vorschau die Rechnungs- bzw. die Lieferscheinnummer nicht generiert werden.<br />Dies geschieht nur unter "Bestellungen". Angezeigt wird jeweils die bereits generierte bzw. vorläufige Nummer.',
	'NOTE_PREVIEW_NO_DATA'                       => 'Momentan ist die Generierung einer Vorschau nicht möglich. Um eine Vorschau generieren zu können, ist mindestens eine Bestellung notwendig.',
	'PROCEED'                                    => 'Aktualisiert',
	'SELECT_CHOOSE'                              => 'Wählen',
	'SELECT_CUSTOMER'                            => 'Kunde: ',
	'SELECT_DISPLAY_LAYOUT_CONTINUOUS'           => 'fortlaufend',
	'SELECT_DISPLAY_LAYOUT_DEFAULT'              => 'Einstellung des Readers',
	'SELECT_DISPLAY_LAYOUT_SINGLE'               => 'Seite für Seite',
	'SELECT_DISPLAY_LAYOUT_TWO'                  => 'Zwei Seiten nebeneinander',
	'SELECT_DISPLAY_OUTPUT'                      => 'Ausgabemodus',
	'SELECT_DISPLAY_OUTPUT_D'                    => 'PDF herunterladen',
	'SELECT_DISPLAY_OUTPUT_I'                    => 'PDF im Browser ausgeben',
	'SELECT_DISPLAY_ZOOM_DEFAULT'                => 'Einstellung des Readers',
	'SELECT_DISPLAY_ZOOM_FULLPAGE'               => 'volle Seite',
	'SELECT_DISPLAY_ZOOM_FULLWIDTH'              => 'volle Breite',
	'SELECT_DISPLAY_ZOOM_REAL'                   => '100%',
	'SELECT_FONT_STYLE_'                         => 'kein Stil',
	'SELECT_FONT_STYLE_B'                        => 'fett',
	'SELECT_FONT_STYLE_I'                        => 'kursiv',
	'SELECT_FONT_STYLE_U'                        => 'unterstrichen',
	'SELECT_ORDERS'                              => 'Bestellnr.: ',
	'SELECT_USE_0'                               => 'nein',
	'SELECT_USE_1'                               => 'ja',
	'TITLE_INVOICE'                              => 'Rechnung',
	'TITLE_MAX_AMOUNT_INVOICES_BULK_PDF'         => 'Maximale Anzahl der Rechnungen je Sammel-PDF',
	'TITLE_MAX_AMOUNT_PACKING_SLIP_BULK_PDF'     => 'Maximale Anzahl der Lieferscheine je Sammel-PDF',
	'TITLE_PACKINGSLIP'                          => 'Lieferschein',
	'USE_DATE_INVOICE'                           => 'Rechnungserstellung',
	'USE_DATE_INVOICE_MAIL'                      => 'E-Mail Rechnungsversand ',
);

==> Gambio v4.5.2.2.zip: Vollversion GX v4.5.2.2/Shopsystem/Dateien/lang/german/original_sections/admin/gm_pdf_action.lang.inc.php <==
<?php
/* --------------------------------------------------------------
	gm_pdf_action.lang.inc.php 2018-07-24
	Gambio GmbH
	http://www.gambio.de
	Copyright (c) 2018 Gambio GmbH
	Released under the GNU General Public License (Version 2)
	[http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

$t_language_text_section_content_array = array(
	'BUTTON_SAVE'                                => 'Speichern',
	'ERROR_NOT_NUMERIC'                          => ' muss numerisch sein!',
	'GM_LOGO_PDF_USE'                            => 'Logo verwenden?',
	'GM_PDF_INVOICE_USE_CURRENT_DATE'            => 'Zu verwendendes Rechnungsdatum',
	'GM_PDF_INVOICE_USE_CURRENT_DATE_FALSE'      => 'Datum festlegen',
	'GM_PDF_INVOICE_USE_CURRENT_DATE_TRUE'       => 'Immer aktuelles Datum verwenden',
	'GM_PDF_INVOICE_USE_MANUAL_DATE_INFO'        => 'Bitte beachte, dass alle neuen Rechnungen mit demselben Datum versehen werden.',
	'GM_PDF_ORDER_STATUS_INVOICE'                => 'Bestellstatus nach Rechnungserstellung',
	'GM_PDF_ORDER_STATUS_INVOICE_MAIL'           => 'Bestellstatus nach E-Mail Rechnungsversand',
	'GM_PDF_ORDER_STATUS_NOT'                    => 'nicht ändern',
	'GM_PDF_PACKING_SLIP_USE_CURRENT_DATE'       => 'Zu verwendendes Lieferscheindatum',
	'GM_PDF_PACKING_SLIP_USE_CURRENT_DATE_FALSE' => 'Datum festlegen',
	'GM_PDF_PACKING_SLIP_USE_CURRENT_DATE_TRUE'  => 'Immer aktuelles Datum verwenden',
	'GM_PDF_PACKING_SLIP_USE_MANUAL_DATE_INFO'   => 'Bitte beachte, dass alle neuen Lieferscheine mit demselben Datum versehen werden.',
	'GM_PDF_TABLE_HEADER_BANK_DATA_COLUMN'       => 'Spalte enthält Bankverbindung',
	'GM_PDF_TABLE_HEADER_BANK_DATA_TOOLTIP'      => 'Einige Zahlungsweisen entfernen beim Erstellen der Rechnung eine Spalte, welche die Bankverbindung enthält und fügen stattdessen eigenen Inhalt in die Rechnung ein.',
	'GM_PDF_TABLE_HEADER_COLUMN_CONTENT'         => 'Spalteninhalt',
	'GM_PDF_TITLE_ALLOW_COPYING'                 => 'Kopieren der internen Texte und Grafiken erlauben',
	'GM_PDF_TITLE_ALLOW_MODIFYING'               => 'Modifizieren des PDF-Dokumentes erlauben',
	'GM_PDF_TITLE_ALLOW_NOTIFYING'               => 'Kommentieren des PDF-Dokumentes erlauben',
	'GM_PDF_TITLE_BOTTOM_MARGIN'                 => 'Einzug unten',
	'GM_PDF_TITLE_CANCEL_FONT_FACE'              => 'Storno-Hinweis',
	'GM_PDF_TITLE_CELL_HEIGHT'                   => 'Höhe der Zellen',
	'GM_PDF_TITLE_CHOOSE_LOGO'                   => 'Logo auswählen',
	'GM_PDF_TITLE_COMPANY_ADRESS_LEFT'           => 'Firmenadresse links',
	'GM_PDF_TITLE_COMPANY_ADRESS_RIGHT'          => 'Firmenadresse rechts',
	'GM_PDF_TITLE_COMPANY_LEFT_FONT_FACE'        => 'Firmenadresse links',
	'GM_PDF_TITLE_COMPANY_RIGHT_FONT_FACE'       => 'Firmenadresse rechts',
	'GM_PDF_TITLE_CONDITIONS'                    => 'AGB',
	'GM_PDF_TITLE_CONDITIONS_FONT_FACE'          => 'AGB/Widerruf',
	'GM_PDF_TITLE_CUSTOMER_ADR_POS'              => 'mm Einzug der Kunden Adresse nach oben',
	'GM_PDF_TITLE_CUSTOMER_FONT_FACE'            => 'Kundenadresse',
	'GM_PDF_TITLE_DEFAULT_FONT_FACE'             => 'Standardschrift',
	'GM_PDF_TITLE_DISPLAY_LAYOUT'                => 'Seitenlayout der PDF im Reader',
	'GM_PDF_TITLE_DISPLAY_ZOOM'                  => 'Zoomfaktor der PDF im Reader',
	'GM_PDF_TITLE_DRAW_COLOR'                    => 'Farbe für Linien',
	'GM_PDF_TITLE_EMAIL_SUBJECT'                 => 'E-Mail Betreff',
	'GM_PDF_TITLE_EMAIL_SUBJECT_INFO'            => '<small>Platzhalter: Rechnungsnr: {INVOICE_ID} Bestellnr: {ORDER_ID} Bestelldatum: {DATE}</small>',
	'GM_PDF_TITLE_EMAIL_TEXT'                    => 'Nachricht',
	'GM_PDF_TITLE_EMAIL_TEXT_INFO'               => '<small>Platzhalter: Anrede: {SALUTATION} Kundenname: {CUSTOMER}  Rechnungsnr: {INVOICE_ID} Bestellnr: {ORDER_ID} Bestelldatum: {DATE}</small>',
	'GM_PDF_TITLE_FIX_HEADER'                    => 'Kopfteil fixieren?',
	'GM_PDF_TITLE_FOOTER_CELL_1'                 => 'Fußteil erste Spalte',
	'GM_PDF_TITLE_FOOTER_CELL_2'                 => 'Fußteil zweite Spalte',
	'GM_PDF_TITLE_FOOTER_CELL_3'                 => 'Fußteil dritte Spalte',
	'GM_PDF_TITLE_FOOTER_CELL_4'                 => 'Fußteil vierte Spalte',
	'GM_PDF_TITLE_FOOTER_FONT_FACE'              => 'Fußteil',
	'GM_PDF_TITLE_HEADING_CANCELLATION_INVOICE'  => 'Überschrift Stornorechnung',
	'GM_PDF_TITLE_HEADING_CONDITIONS'            => 'Überschrift AGB',
	'GM_PDF_TITLE_HEADING_CONDITIONS_FONT_FACE'  => 'Überschrift AGB/Widerruf',
	'GM_PDF_TITLE_HEADING_FONT_FACE'             => 'Überschrift',
	'GM_PDF_TITLE_HEADING_INFO_TEXT_INVOICE'     => 'Überschrift Rechnungshinweis',
	'GM_PDF_TITLE_HEADING_INFO_TEXT_PACKINGSLIP' => 'Überschrift Lieferhinweis',
	'GM_PDF_TITLE_HEADING_INVOICE'               => 'Überschrift Rechnung',
	'GM_PDF_TITLE_HEADING_MARGIN_BOTTOM'         => 'Einzug der Überschrift nach unten',
	'GM_PDF_TITLE_HEADING_MARGIN_TOP'            => 'Einzug der Überschrift nach oben',
	'GM_PDF_TITLE_HEADING_ORDER_FONT_FACE'       => 'Bestell-Tabellenkopf',
	'GM_PDF_TITLE_HEADING_ORDER_INFO_FONT_FACE'  => 'Überschrift Hinweis',
	'GM_PDF_TITLE_HEADING_PACKINGSLIP'           => 'Überschrift Lieferschein',
	'GM_PDF_TITLE_HEADING_WITHDRAWAL'            => 'Überschrift Widerruf',
	'GM_PDF_TITLE_INFO_TEXT_INVOICE'             => 'Hinweistext Rechnung',
	'GM_PDF_TITLE_INFO_TEXT_PACKINGSLIP'         => 'Hinweistext Lieferschein',
	'GM_PDF_TITLE_INFO_TITLE_INVOICE'            => 'Hinweistitel Rechnung',
	'GM_PDF_TITLE_INFO_TITLE_PACKINGSLIP'        => 'Hinweistitel Lieferschein',
	'GM_PDF_TITLE_INVOICES_EMAIL_SUBJECT'        => 'E-Mail Betreff (mehrere Rechnungen)',
	'GM_PDF_TITLE_INVOICES_EMAIL_SUBJECT_INFO'   => '<small>Platzhalter: Rechnungsnummern: {INVOICE_NUMBERS} Bestellnr: {ORDER_ID} Bestelldatum: {DATE}</small>',
	'GM_PDF_TITLE_LEFT_MARGIN'                   => 'Einzug links',
	'GM_PDF_TITLE_ORDER_FONT_FACE'               => 'Bestell-Tabelle',
	'GM_PDF_TITLE_ORDER_INFO_FONT_FACE'          => 'Hinweistext',
	'GM_PDF_TITLE_ORDER_INFO_MARGIN_TOP'         => 'Einzug des Hinweises nach oben',
	'GM_PDF_TITLE_ORDER_TOTAL_FONT_FACE'         => 'Bestell-Zusammenfassung',
	'GM_PDF_TITLE_RIGHT_MARGIN'                  => 'Einzug rechts',
	'GM_PDF_TITLE_TOP_MARGIN'                    => 'Einzug oben',
	'GM_PDF_TITLE_USE_CONDITIONS'                => 'AGB verwenden?',
	'GM_PDF_TITLE_USE_CUSTOMER_CODE'             => 'Kundennummer verwenden?',
	'GM_PDF_TITLE_USE_CUSTOMER_COMMENT'          => 'Kundenkommentar verwenden?',
	'GM_PDF_TITLE_USE_DATE'                      => 'aktuelles Datum verwenden?',
	'GM_PDF_TITLE_USE_FOOTER'                    => 'Fußteil verwenden?',
	'GM_PDF_TITLE_USE_HEADER'                    => 'Kopfteil verwenden?',
	'GM_PDF_TITLE_USE_INFO'                      => 'Hinweis verwenden?',
	'GM_PDF_TITLE_USE_INFO_TEXT'                 => 'Hinweistext verwenden?',
	'GM_PDF_TITLE_USE_INVOICE_CODE'              => 'Rechnungsnummer verwenden?',
	'GM_PDF_TITLE_USE_ORDER_CODE'                => 'Bestellnummer verwenden?',
	'GM_PDF_TITLE_USE_ORDER_DATE'                => 'Bestelldatum verwenden?',
	'GM_PDF_TITLE_USE_PACKING_CODE'              => 'Liefernummer verwenden?',
	'GM_PDF_TITLE_USE_PRODUCTS_MODEL'            => 'Spalte "Artikel Nr" Verwenden?',
	'GM_PDF_TITLE_USE_PROTECTION'                => 'PDF Dokument schützen?',
	'GM_PDF_TITLE_USE_WITHDRAWAL'                => 'Widerruf verwenden?',
	'GM_PDF_TITLE_WITHDRAWAL'                    => 'Widerruf',
	'MENU_TITLE_CONDITIONS'                      => 'AGB/Widerruf',
	'MENU_TITLE_CONF'                            => 'Konfiguration',
	'MENU_TITLE_CONTENT'                         => 'Inhalt',
	'MENU_TITLE_DISPLAY'                         => 'Anzeige',
	'MENU_TITLE_EMAIL_TEXT'                      => 'E-Mail Rechnung',
	'MENU_TITLE_FONTS'                           => 'Schriften',
	'MENU_TITLE_FOOTER'                          => 'Fußteil',
	'MENU_TITLE_HEADER'                          => 'Kopfteil',
	'MENU_TITLE_INVOICING'                       => 'Bestellstatus und Rechnungs-/Lieferscheindatum',
	'MENU_TITLE_LAYOUT'                          => 'Layout',
	'MENU_TITLE_LOGO'                            => 'Logo',
	'MENU_TITLE_ORDER_INFO'                      => 'Hinweistexte',
	'MENU_TITLE_PREVIEW'                         => 'Vorschau',
	'MENU_TITLE_PROTECTION'                      => 'Sicherheit',
	'NOTE_PREVIEW'                               => 'Bitte beachte, dass in der Vorschau die Rechnungs- bzw. die Lieferscheinnummern nicht generiert werden.<br />Dies geschieht nur unter "Bestellungen". Angezeigt wird jeweils die bereits generierte bzw. vorläufige Nummer.',
	'NOTE_PREVIEW_NO_DATA'                       => 'Momentan ist die Generierung einer Vorschau nicht möglich. Um eine Vorschau generieren zu können, ist mindestens eine Bestellung notwendig.',
	'PROCEED'                                    => 'Aktualisiert',
	'SELECT_CHOOSE'                              => 'Wählen',
	'SELECT_CUSTOMER'                            => 'Kunde: ',
	'SELECT_DISPLAY_LAYOUT_CONTINUOUS'           => 'fortlaufend',
	'SELECT_DISPLAY_LAYOUT_DEFAULT'              => 'Einstellung des Readers',
	'SELECT_DISPLAY_LAYOUT_SINGLE'               => 'Seite für Seite',
	'SELECT_DISPLAY_LAYOUT_TWO'                  => 'Zwei Seiten nebeneinander',
	'SELECT_DISPLAY_OUTPUT'                      => 'Ausgabemodus',
	'SELECT_DISPLAY_OUTPUT_D'                    => 'PDF herunterladen',
	'SELECT_DISPLAY_OUTPUT_I'                    => 'PDF im Browser ausgeben',
	'SELECT_DISPLAY_ZOOM_DEFAULT'                => 'Einstellung des Readers',
	'SELECT_DISPLAY_ZOOM_FULLPAGE'               => 'volle Seite',
	'SELECT_DISPLAY_ZOOM_FULLWIDTH'              => 'volle Breite',
	'SELECT_DISPLAY_ZOOM_REAL'                   => '100%',
	'SELECT_FONT_STYLE_'                         => 'kein Stil',
	'SELECT_FONT_STYLE_B'                        => 'fett',
	'SELECT_FONT_STYLE_I'                        => 'kursiv',
	'SELECT_FONT_STYLE_U'                        => 'unterstrichen',
	'SELECT_ORDERS'                              => 'Bestellnr.: ',
	'SELECT_USE_0'                               => 'nein',
	'SELECT_USE_1'                               => 'ja',
	'TITLE_INVOICE'                              => 'Rechnung',
	'TITLE_MAX_AMOUNT_INVOICES_BULK_PDF'         => 'Maximale Anzahl der Rechnungen je Sammel-PDF',
	'TITLE_MAX_AMOUNT_PACKING_SLIP_BULK_PDF'     => 'Maximale Anzahl der Lieferscheine je Sammel-PDF',
	'TITLE_PACKINGSLIP'                          => 'Lieferschein',
	'USE_DATE_INVOICE'                           => 'Rechnungserstellung',
	'USE_DATE_INVOICE_MAIL'                      => 'E-Mail Rechnungsversand ',
);
